@@ -1,8 +1,10 @@
+import os.path
 import unittest
 
 import ddt
 
 from iker.common.utils.config import Config, ConfigVisitor
+from iker_tests import resources_directory
 
 
 @ddt.ddt
@@ -12,6 +14,29 @@ class ConfigTest(unittest.TestCase):
         config = Config()
         self.assertEqual(len(config), 0)
 
+    def test_set(self):
+        config = Config()
+
+        tuples = [
+            ("dummy_section_1", "dummy_option_1", "True"),
+            ("dummy_section_1", "dummy_option_2", "False"),
+            ("dummy_section_1", "dummy_option_3", "1"),
+            ("dummy_section_1", "dummy_option_4", "-1"),
+            ("dummy_section_1", "dummy_option_5", "1.0"),
+            ("dummy_section_1", "dummy_option_6", "-1.0"),
+            ("dummy_section_1", "dummy_option_7", "1.e+0"),
+            ("dummy_section_1", "dummy_option_8", "-1.e-0"),
+            ("dummy_section_1", "dummy_option_9", "dummy_value_alpha"),
+        ]
+
+        for section, option, value in tuples:
+            config.set(section, option, value)
+
+        for section, option, value in tuples:
+            self.assertTrue(config.has_section(section))
+            self.assertTrue(config.has(section, option))
+            self.assertEqual(config.get(section, option), value)
+
     def test_update(self):
         config = Config()
 
@@ -271,7 +296,35 @@ class ConfigTest(unittest.TestCase):
         self.assertEqual(config.get("dummy_section_1", "dummy_option_9"), "dummy_value_alpha")
 
         self.assertFalse(config.restore())
+        self.assertEqual(len(config), 0)
 
+    def test_restore__from_file(self):
+        config = Config(os.path.join(resources_directory, "unittest/config/config.cfg"))
+
+        tuples = [
+            ("dummy_section_1", "dummy_option_1", "True"),
+            ("dummy_section_1", "dummy_option_2", "False"),
+            ("dummy_section_1", "dummy_option_3", "1"),
+            ("dummy_section_1", "dummy_option_4", "-1"),
+            ("dummy_section_1", "dummy_option_5", "1.0"),
+            ("dummy_section_1", "dummy_option_6", "-1.0"),
+            ("dummy_section_1", "dummy_option_7", "1.e+0"),
+            ("dummy_section_1", "dummy_option_8", "-1.e-0"),
+            ("dummy_section_1", "dummy_option_9", "dummy_value_alpha"),
+        ]
+
+        self.assertTrue(config.restore())
+        self.assertEqual(len(config), len(tuples))
+
+        for section, option, value in tuples:
+            self.assertTrue(config.has_section(section))
+            self.assertTrue(config.has(section, option))
+            self.assertEqual(config.get(section, option), value)
+
+    def test_restore__file_not_found(self):
+        config = Config(os.path.join(resources_directory, "unittest/config/missing_config.cfg"))
+
+        self.assertFalse(config.restore())
         self.assertEqual(len(config), 0)
 
     def test_persist(self):
@@ -302,7 +355,6 @@ class ConfigTest(unittest.TestCase):
         self.assertEqual(config.get("dummy_section_1", "dummy_option_9"), "dummy_value_alpha")
 
         self.assertFalse(config.persist())
-
         self.assertEqual(len(config), len(tuples))
 
 
