@@ -1,8 +1,8 @@
+import dataclasses
 import datetime
 import math
 import unittest
 from collections.abc import Mapping, Sequence
-from dataclasses import dataclass
 from typing import SupportsFloat, SupportsInt
 
 import ddt
@@ -13,7 +13,7 @@ from iker.common.utils.jsonutils import json_reformat, json_sanitize, json_trave
 from iker.common.utils.randutils import randomizer
 
 
-@dataclass(eq=True, frozen=True)
+@dataclasses.dataclass(eq=True, frozen=True)
 class PrefixedStr(object):
     prefix: str
     value: str
@@ -22,7 +22,7 @@ class PrefixedStr(object):
         return self.prefix + "::" + self.value
 
 
-@dataclass(eq=True, frozen=True)
+@dataclasses.dataclass(eq=True, frozen=True)
 class MultipliedInt(SupportsInt):
     value: int
     multiplier: int = 1
@@ -31,7 +31,7 @@ class MultipliedInt(SupportsInt):
         return self.value * self.multiplier
 
 
-@dataclass(eq=True, frozen=True)
+@dataclasses.dataclass(eq=True, frozen=True)
 class MultipliedFloat(SupportsFloat):
     value: float
     multiplier: float = 1
@@ -40,7 +40,7 @@ class MultipliedFloat(SupportsFloat):
         return self.value * self.multiplier
 
 
-@dataclass(frozen=True)
+@dataclasses.dataclass(frozen=True)
 class WrappedList(Sequence):
     value: list
 
@@ -51,7 +51,7 @@ class WrappedList(Sequence):
         return self.value[index]
 
 
-@dataclass(frozen=True)
+@dataclasses.dataclass(frozen=True)
 class WrappedDict(Mapping):
     value: dict
 
@@ -67,8 +67,7 @@ class WrappedDict(Mapping):
 
 @ddt.ddt
 class JsonUtilsTest(unittest.TestCase):
-
-    @ddt.data(
+    data_json_get = [
         (None, [], None),
         (True, [], True),
         (False, [], False),
@@ -153,12 +152,14 @@ class JsonUtilsTest(unittest.TestCase):
             [0],
             None,
         ),
-    )
+    ]
+
+    @ddt.idata(data_json_get)
     @ddt.unpack
     def test_json_get(self, data, node_path, expect):
         self.assertTrue(json_compare(json_get(data, *node_path), expect))
 
-    @ddt.data(
+    data_json_get__comprehensive = [
         (
             {
                 "none": None,
@@ -294,8 +295,10 @@ class JsonUtilsTest(unittest.TestCase):
                     },
                 ),
             ],
-        )
-    )
+        ),
+    ]
+
+    @ddt.idata(data_json_get__comprehensive)
     @ddt.unpack
     def test_json_get__comprehensive(self, data, queries):
         for node_path, expect in queries:
@@ -440,7 +443,7 @@ class JsonUtilsTest(unittest.TestCase):
             self.assertTrue(json_set(obj, v, asterisk))
         self.assertTrue(json_compare(obj, list(range(1000))))
 
-    @ddt.data(
+    data_json_traverse = [
         (None, None),
         (True, True),
         (False, False),
@@ -643,7 +646,9 @@ class JsonUtilsTest(unittest.TestCase):
                     [None, True, False, 1, -1, 0, 1., -1., 0., 1e9, -1e-9, math.nan, math.inf, -math.inf, "", "dummy"],
             },
         ),
-    )
+    ]
+
+    @ddt.idata(data_json_traverse)
     @ddt.unpack
     def test_json_traverse(self, data, expect):
         self.assertTrue(json_compare(json_traverse(data), expect))
@@ -741,7 +746,7 @@ class JsonUtilsTest(unittest.TestCase):
                                                    stop_func=stop_func),
                                      expect))
 
-    @ddt.data(
+    data_json_reformat = [
         (None, None),
         (True, True),
         (False, False),
@@ -944,22 +949,27 @@ class JsonUtilsTest(unittest.TestCase):
                     [None, True, False, 1, -1, 0, 1., -1., 0., 1e9, -1e-9, math.nan, math.inf, -math.inf, "", "dummy"],
             },
         ),
-    )
+    ]
+
+    @ddt.idata(data_json_reformat)
     @ddt.unpack
     def test_json_reformat(self, data, expect):
         self.assertTrue(json_compare(json_reformat(data), expect))
 
-    @ddt.data(
+    data_json_reformat__unregistered_type = [
         (set(),),
         (object(),),
         ([set(), object()],),
         ({"set": set(), "object": object()},),
-    )
+    ]
+
+    @ddt.idata(data_json_reformat__unregistered_type)
+    @ddt.unpack
     def test_json_reformat__unregistered_type(self, data):
         with self.assertRaises(ValueError):
             json_reformat(data)
 
-    @ddt.data(
+    data_json_sanitize = [
         (None, None),
         (True, True),
         (False, False),
@@ -1173,7 +1183,9 @@ class JsonUtilsTest(unittest.TestCase):
                 "key::set": [1, 2, 3, 4, 5, 6, 7],
             },
         ),
-    )
+    ]
+
+    @ddt.idata(data_json_sanitize)
     @ddt.unpack
     def test_json_sanitize(self, data, expect):
         self.assertTrue(json_compare(json_sanitize(data), expect))
